pub trait MapSize {
type Output;
// Required method
fn map_size() -> Vec2D<Self::Output>;
}Expand description
A trait providing a method to define the size of a 2D map.
This is used to determine the dimensions of the map for wrapping operations.
Required Associated Types
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.
Implementations on Foreign Types
Sourceimpl MapSize for I32F0
Implementation of the MapSize trait for the I32F0 fixed-point number type.
impl MapSize for I32F0
Implementation of the MapSize trait for the I32F0 fixed-point number type.
Sourceimpl MapSize for I32F32
Implementation of the MapSize trait for the I32F32 fixed-point number type.
impl MapSize for I32F32
Implementation of the MapSize trait for the I32F32 fixed-point number type.
Sourceimpl MapSize for I96F32
Implementation of the MapSize trait for the I96F32 fixed-point number type.
impl MapSize for I96F32
Implementation of the MapSize trait for the I96F32 fixed-point number type.